==> mingw-w64-freecad-0.21.2-4.src.tar.zst: FreeCAD-0.21.2/src/App/Resources/translations/App_zh-TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh-TW" sourcelanguage="en">
  <context>
    <name>LinkParams</name>
    <message>
      <location filename="../../Link.cpp" line="119"/>
      <source>Stores the last user choice of whether to apply CopyOnChange setup to all links
that reference the same configurable object</source>
      <translation type="unfinished">Stores the last user choice of whether to apply CopyOnChange setup to all links
that reference the same configurable object</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Application.cpp" line="441"/>
      <source>Unnamed</source>
      <translation>未命名</translation>
    </message>
  </context>
  <context>
    <name>App::Origin</name>
    <message>
      <location filename="../../Origin.cpp" line="140"/>
      <source>X-axis</source>
      <translation>X軸</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="141"/>
      <source>Y-axis</source>
      <translation>Y軸</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="142"/>
      <source>Z-axis</source>
      <translation>Z軸</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="143"/>
      <source>XY-plane</source>
      <translation>XY平面</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="144"/>
      <source>XZ-plane</source>
      <translation>XZ平面</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="145"/>
      <source>YZ-plane</source>
      <translation>YZ平面</translation>
    </message>
  </context>
  <context>
    <name>App::OriginGroupExtension</name>
    <message>
      <location filename="../../OriginGroupExtension.cpp" line="134"/>
      <source>Origin</source>
      <translation>原點</translation>
    </message>
  </context>
</TS>

==> mingw-w64-freecad-1.0rc2-1.src.tar.zst: FreeCAD-1.0rc2/src/App/Resources/translations/App_zh-TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh-TW" sourcelanguage="en">
  <context>
    <name>LinkParams</name>
    <message>
      <location filename="../../Link.cpp" line="118"/>
      <source>Stores the last user choice of whether to apply CopyOnChange setup to all links
that reference the same configurable object</source>
      <translation>儲存最後的使用者對是否要將 CopyOnChange 設定套用至引用相同可配置物件的所有連結的選擇</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Application.cpp" line="463"/>
      <source>Unnamed</source>
      <translation>未命名</translation>
    </message>
  </context>
  <context>
    <name>App::Origin</name>
    <message>
      <location filename="../../Origin.cpp" line="142"/>
      <source>X-axis</source>
      <translation>X軸</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="143"/>
      <source>Y-axis</source>
      <translation>Y軸</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="144"/>
      <source>Z-axis</source>
      <translation>Z軸</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="145"/>
      <source>XY-plane</source>
      <translation>XY平面</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="146"/>
      <source>XZ-plane</source>
      <translation>XZ平面</translation>
    </message>
    <message>
      <location filename="../../Origin.cpp" line="147"/>
      <source>YZ-plane</source>
      <translation>YZ平面</translation>
    </message>
  </context>
  <context>
    <name>App::OriginGroupExtension</name>
    <message>
      <location filename="../../OriginGroupExtension.cpp" line="134"/>
      <source>Origin</source>
      <translation>原點</translation>
    </message>
  </context>
</TS>
